package com.bpcl.lpg.core.dao.impl;

import de.hybris.platform.servicelayer.search.paginated.util.PaginatedSearchUtils;
import de.hybris.platform.servicelayer.search.paginated.PaginatedFlexibleSearchParameter;
import de.hybris.platform.core.servicelayer.data.SearchPageData;
import java.util.List;
import de.hybris.platform.servicelayer.search.SearchResult;
import java.util.Collection;
import org.apache.commons.collections.CollectionUtils;
import de.hybris.platform.servicelayer.exceptions.AmbiguousIdentifierException;
import java.util.Map;
import de.hybris.platform.servicelayer.search.FlexibleSearchQuery;
import java.util.HashMap;
import de.hybris.platform.servicelayer.util.ServicesUtil;
import com.bpcl.lpg.core.model.LpgSafetyInspectionModel;
import java.util.Date;
import javax.annotation.Resource;
import de.hybris.platform.servicelayer.search.FlexibleSearchService;
import de.hybris.platform.servicelayer.search.paginated.PaginatedFlexibleSearchService;
import com.bpcl.lpg.core.dao.BpclSafetyInspectionDao;

public class BpclSafetyInspectionDaoImpl implements BpclSafetyInspectionDao
{
    private PaginatedFlexibleSearchService paginatedFlexibleSearchService;
    private static final String INSPECTION_DETAILS_BY_CUSTOMERMOBILENUMBER_QUERY = "SELECT {pk} FROM {LpgSafetyInspection} WHERE {customerMobileNumber}=?customerMobileNumber AND {safetyInspectionDate} >= ?startTime";
    private static final String INSPECTION_DETAILS_BY_CONSUMERNUMBER_QUERY = "SELECT {pk} FROM {LpgSafetyInspection} WHERE {customerNumber}=?customerNumber AND {distributorCode}=?distributorCode AND {safetyInspectionDate} >= ?startTime";
    private static final String INSPECTION_DETAILS_BY_LPGID_QUERY = "SELECT {pk} FROM {LpgSafetyInspection} WHERE {lpgId}=?lpgId AND {safetyInspectionDate} >= ?startTime";
    private static final String INSPECTION_DETAILS_BY_ID = "SELECT {pk} FROM {LpgSafetyInspection} WHERE {id}=?id";
    @Resource
    private FlexibleSearchService flexibleSearchService;
    
    public LpgSafetyInspectionModel getInspectionDetailsByConsumerNo(final String consumerNo, final String distCode, final Date startDate) {
        ServicesUtil.validateParameterNotNullStandardMessage("customerNumber", (Object)consumerNo);
        final Map<String, Object> params = new HashMap<String, Object>();
        params.put("customerNumber", consumerNo);
        params.put("distributorCode", distCode);
        params.put("startTime", startDate);
        final FlexibleSearchQuery searchQuery = new FlexibleSearchQuery("SELECT {pk} FROM {LpgSafetyInspection} WHERE {customerNumber}=?customerNumber AND {distributorCode}=?distributorCode AND {safetyInspectionDate} >= ?startTime");
        searchQuery.addQueryParameters((Map)params);
        final SearchResult<LpgSafetyInspectionModel> searchResult = (SearchResult<LpgSafetyInspectionModel>)this.flexibleSearchService.search(searchQuery);
        final List<LpgSafetyInspectionModel> inspectionDetailsList = searchResult.getResult();
        if (inspectionDetailsList.size() > 1) {
            throw new AmbiguousIdentifierException("Found" + inspectionDetailsList.size() + "Records with the ConsumerNumber value:customerNumberwhich should be unique");
        }
        return CollectionUtils.isNotEmpty((Collection)inspectionDetailsList) ? inspectionDetailsList.get(0) : null;
    }
    
    public LpgSafetyInspectionModel getInspectionDetailsByContactNumber(final String contactNumber, final Date startDate) {
        ServicesUtil.validateParameterNotNullStandardMessage("customerMobileNumber", (Object)contactNumber);
        final Map<String, Object> params = new HashMap<String, Object>();
        params.put("customerMobileNumber", contactNumber);
        params.put("startTime", startDate);
        final FlexibleSearchQuery searchQuery = new FlexibleSearchQuery("SELECT {pk} FROM {LpgSafetyInspection} WHERE {customerMobileNumber}=?customerMobileNumber AND {safetyInspectionDate} >= ?startTime");
        searchQuery.addQueryParameters((Map)params);
        final SearchResult<LpgSafetyInspectionModel> searchResult = (SearchResult<LpgSafetyInspectionModel>)this.flexibleSearchService.search(searchQuery);
        final List<LpgSafetyInspectionModel> inspectionDetailsList = searchResult.getResult();
        if (inspectionDetailsList.size() > 1) {
            throw new AmbiguousIdentifierException("Found" + inspectionDetailsList.size() + "Records with the contactNumber value:customerMobileNumberwhich should be unique");
        }
        return CollectionUtils.isNotEmpty((Collection)inspectionDetailsList) ? inspectionDetailsList.get(0) : null;
    }
    
    public LpgSafetyInspectionModel getInspectionDetailsByLpgID(final String lpgID, final Date startDate) {
        ServicesUtil.validateParameterNotNullStandardMessage("lpgId", (Object)lpgID);
        final Map<String, Object> params = new HashMap<String, Object>();
        params.put("lpgId", lpgID);
        params.put("startTime", startDate);
        final FlexibleSearchQuery searchQuery = new FlexibleSearchQuery("SELECT {pk} FROM {LpgSafetyInspection} WHERE {lpgId}=?lpgId AND {safetyInspectionDate} >= ?startTime");
        searchQuery.addQueryParameters((Map)params);
        final SearchResult<LpgSafetyInspectionModel> searchResult = (SearchResult<LpgSafetyInspectionModel>)this.flexibleSearchService.search(searchQuery);
        final List<LpgSafetyInspectionModel> inspectionDetailsList = searchResult.getResult();
        if (inspectionDetailsList.size() > 1) {
            throw new AmbiguousIdentifierException("Found" + inspectionDetailsList.size() + "Records with the LPGID value:lpgIdwhich should be unique");
        }
        return CollectionUtils.isNotEmpty((Collection)inspectionDetailsList) ? inspectionDetailsList.get(0) : null;
    }
    
    public SearchPageData<LpgSafetyInspectionModel> getSafetyInspectionDetailsForExport(final Date startDate, final Date endDate, final int pageSize, final int currentPage) {
        final StringBuilder query = new StringBuilder("SELECT {pk} from {").append("LpgSafetyInspection").append("} WHERE {").append("sentToLpgNxt").append("} = 0").append(" AND {").append("safetyInspectionDate").append("} > ?").append("startDate").append(" AND {").append("safetyInspectionDate").append("} < ?").append("endDate");
        final Map<String, Object> param = new HashMap<String, Object>();
        param.put("startDate", startDate);
        param.put("endDate", endDate);
        final FlexibleSearchQuery flexibleSearchQuery = new FlexibleSearchQuery(query);
        flexibleSearchQuery.addQueryParameters((Map)param);
        return (SearchPageData<LpgSafetyInspectionModel>)this.paginatedFlexibleSearchService.search(this.createPageableData(flexibleSearchQuery, pageSize, currentPage));
    }
    
    public LpgSafetyInspectionModel getSafetyInspectionDetailsBySafetyInspectionId(final String safetyInspectionId) {
        ServicesUtil.validateParameterNotNullStandardMessage("id", (Object)safetyInspectionId);
        final Map<String, Object> params = new HashMap<String, Object>();
        params.put("id", safetyInspectionId);
        final FlexibleSearchQuery searchQuery = new FlexibleSearchQuery("SELECT {pk} FROM {LpgSafetyInspection} WHERE {id}=?id");
        searchQuery.addQueryParameters((Map)params);
        final SearchResult<LpgSafetyInspectionModel> searchResult = (SearchResult<LpgSafetyInspectionModel>)this.flexibleSearchService.search(searchQuery);
        final List<LpgSafetyInspectionModel> inspectionDetailsList = searchResult.getResult();
        return CollectionUtils.isNotEmpty((Collection)inspectionDetailsList) ? inspectionDetailsList.get(0) : null;
    }
    
    private PaginatedFlexibleSearchParameter createPageableData(final FlexibleSearchQuery query, final int batchSize, final int currentPage) {
        final SearchPageData<LpgSafetyInspectionModel> searchPageData = (SearchPageData<LpgSafetyInspectionModel>)PaginatedSearchUtils.createSearchPageDataWithPagination(batchSize, currentPage, (boolean)Boolean.TRUE);
        final PaginatedFlexibleSearchParameter parameter = new PaginatedFlexibleSearchParameter();
        parameter.setFlexibleSearchQuery(query);
        parameter.setSearchPageData((SearchPageData)searchPageData);
        return parameter;
    }
    
    public void setPaginatedFlexibleSearchService(final PaginatedFlexibleSearchService paginatedFlexibleSearchService) {
        this.paginatedFlexibleSearchService = paginatedFlexibleSearchService;
    }
}
